@@ -22,9 +22,9 @@ from tendenci.core.event_logs.models import EventLog
 
 class CorporateMembershipTypeAdmin(admin.ModelAdmin):
     list_display = ['name', 'price', 'renewal_price', 'membership_type',
-                     'admin_only', 'status_detail', 'order']
+                     'admin_only', 'status_detail', 'position']
     list_filter = ['name', 'price', 'status_detail']
-
+    list_editable = ['position']
     fieldsets = (
         (None, {'fields': ('name', 'price', 'renewal_price',
                            'membership_type', 'description')}),
@@ -32,11 +32,18 @@ class CorporateMembershipTypeAdmin(admin.ModelAdmin):
                                     ('apply_threshold', 'individual_threshold',
                                     'individual_threshold_price',)}),
         ('Other Options', {'fields': (
-            'order', ('admin_only', 'status'), 'status_detail')}),
+            'position', ('admin_only', 'status'), 'status_detail')}),
     )
 
     form = CorporateMembershipTypeForm
 
+    class Media:
+        js = (
+            '%sjs/jquery-1.6.2.min.js' % settings.STATIC_URL,
+            '%sjs/jquery-ui-1.8.17.custom.min.js' % settings.STATIC_URL,
+            '%sjs/admin/admin-list-reorder.js' % settings.STATIC_URL,
+        )
+
     def save_model(self, request, object, form, change):
         instance = form.save(commit=False)
 
@@ -111,7 +118,7 @@ class FieldInline(admin.StackedInline):
     fieldsets = (
         (None, {'fields': (('label', 'field_type'),
         ('choices', 'field_layout'), 'size', ('required', 'visible', 'no_duplicates', 'admin_only'), 
-            'instruction', 'default_value', 'css_class', 'order')}),
+            'instruction', 'default_value', 'css_class', 'position')}),
     )
     #raw_id_fields = ("page", 'section', 'field') 
     template = "corporate_memberships/admin/stacked.html"
@@ -134,7 +141,7 @@ class CorpAppAdmin(admin.ModelAdmin):
         js = (
             '%sjs/jquery-1.4.2.min.js' % settings.STATIC_URL,
             '%sjs/jquery_ui_all_custom/jquery-ui-1.8.5.custom.min.js' % settings.STATIC_URL,
-            '%sjs/admin/inline_ordering2.js' % settings.STATIC_URL,
+            '%sjs/admin/dynamic-inlines-with-sort.js' % settings.STATIC_URL,
             '%sjs/global/tinymce.event_handlers.js' % settings.STATIC_URL,
             #'%sjs/admin/corpapp.js' % settings.STATIC_URL,
         )
