@@ -770,7 +770,7 @@ class Reg8nConfPricingForm(BetterModelForm):
             'allow_anonymous',
             'allow_user',
             'allow_member',
-            'display_order'
+            'position'
          ]
 
         fieldsets = [('Registration Pricing', {
@@ -783,7 +783,7 @@ class Reg8nConfPricingForm(BetterModelForm):
                     'allow_anonymous',
                     'allow_user',
                     'allow_member',
-                    'display_order'
+                    'position'
                     ],
           'legend': '',
           'classes': ['boxy-grey'],
