@@ -920,7 +920,7 @@ def gen_pricing_dict(price, qualifies, failure_type, admin=False):
             'amount': price.price,
             'qualifies': qualifies,
             'failure_type': failure_type,
-            'display_order': price.display_order
+            'position': price.position
         }
     else:
         if now >= price.start_dt and now <= price.end_dt:
@@ -929,7 +929,7 @@ def gen_pricing_dict(price, qualifies, failure_type, admin=False):
                 'amount': price.price,
                 'qualifies': qualifies,
                 'failure_type': failure_type,
-                'display_order': price.display_order
+                'position': price.position
             }
         else:
             pricing = {}
@@ -1064,8 +1064,8 @@ def get_pricing(user, event, pricing=None):
     sorted_pricing_list = []
     if pricing_list:
         sorted_pricing_list = sorted(
-            pricing_list,
-            key=lambda k:( k['display_order'], k['amount'])
+            pricing_list, 
+            key=lambda k:( k['position'], k['amount'])
         )
 
         # set a default pricing on the first
