@@ -31,7 +31,7 @@ class Group(TendenciBaseModel):
     notes = models.TextField(blank=True)
     members = models.ManyToManyField(User, through='GroupMembership')
 
-    group = models.OneToOneField(AuthGroup, null=True, default=None, on_delete=models.SET_NULL)
+    group = models.OneToOneField(AuthGroup, null=True, default=None)
     permissions = models.ManyToManyField(Permission, related_name='group_permissions', blank=True)
     # use_for_membership = models.BooleanField(_('User for Membership Only'), default=0, blank=True)
 
@@ -57,34 +57,39 @@ class Group(TendenciBaseModel):
         if not self.slug:
             self.slug = slugify(self.name)
 
-        if self.name and not self.group:
-            try:
-                group = AuthGroup.objects.create(name=self.name)
-            except IntegrityError:
-                connection._rollback()
-                id = AuthGroup.objects.count()
-                group = AuthGroup.objects.create(name=" ".join([self.name, str(id)]))
-            group.save()
-            self.group = group
-
-        elif self.name and self.group:
-            self.group.name = self.name
-            try:
-                self.group.save()
-            except IntegrityError:
-                connection._rollback()
-
         # add the default entity
         if not self.entity:
             self.entity = Entity.objects.first()
 
         super(Group, self).save(force_insert, force_update, *args, **kwargs)
 
+        if not self.group:
+            # create auth group if not exists
+            # note that the name of auth group is also unique
+            group_name = self.get_unique_auth_group_name()
+            self.group = AuthGroup.objects.create(name=group_name)
+            self.save()
+
     @property
     def active_members(self):
         return GroupMembership.objects.filter(
             group=self, status=True, status_detail='active')
 
+    def get_unique_auth_group_name(self):
+        # get the unique name for auth group.
+        # the max length of the name of the auth group is 80.
+        name = self.name
+        if not name:
+            name = str(self.id)
+
+        if len(name) > 80:
+            name = name[:80]
+
+        if AuthGroup.objects.filter(name=name).exists():
+            name = 'User Group %d' % self.id
+
+        return name
+
     def is_member(self, user):
         # impersonation
         user = getattr(user, 'impersonated_user', user)
